###########################
Clustering (``clustering``)
###########################

.. py:currentmodule:: Orange.clustering

.. index:: clustering

Orange offers three clustering methods: k-means clustering, hierarchical clustering with different link functions, and consensus clustering, which is still much under development.

.. toctree::
   :glob:
   :maxdepth: 4

   Orange.clustering.kmeans
   Orange.clustering.hierarchical
   Orange.clustering.consensus
   
